@@ -106,26 +106,12 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
 #        records.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
         records.arrData[3][i]=XYder
         records.arrData[4][i]=lastindexovertrigger
-#        if(records.arrData[3][i]>data.Trigger): #over trigger
-#            lastindexovertrigger=i
-        
-            
-
-#    for i in range(max(start,  5), records.Index-data.Derivation):     
-#        t=i*(records.Sampling_interval*records.Value_smoothing)/1000
-#        if(data.QuickMode==True or t>data.DelayStartTime):
-#            Xder=records.arrData[1][i] - records.arrData[1][i-data.Derivation] #X  Now - 50 sec ago
-#            Yder=records.arrData[2][i] - records.arrData[2][i-data.Derivation]  #Y  Now - 50 sec ago
-#            XYder=abs(Xder)+abs(Yder) #summ of both absolute Derivations
-#        else: #During delayed phase, do not use data
-#            Xder=0
-#            Yder=0
-#            XYder=0
-#        records.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
-
-
+        if(records.arrData[3][i]>data.Trigger): #over trigger
+            lastindexovertrigger=i
 
 
+#    for i in range(0,  records.Index-data.Derivation):     
+#        print i,  records.arrData[0][i], records.arrData[3][i],  records.arrData[4][i]
 
 
 
@@ -292,10 +278,10 @@ def GenerateGraph(self,  QtGui):
             if(x0<x1): 
                 t=(x1-x0)*Xscale/6        
 #                print x0,  x1
-                if(t>30): color="#009100" #green
-                elif(t>15): color="#005000" #dark green
-                elif(t>7): color="#97320e" #orange
-                else: color="#6D0000" #dark red                   
+                if(t>30): color="#009100" #green for 30 minutes and longer
+                elif(t>15): color="#005000" #dark green for 15 .. 29 minutes
+                elif(t>7): color="#97320e" #orange for 7 .. 14 minutes
+                else: color="#6D0000" #dark red for under 7 minutes
                 paint.setBrush(QtGui.QColor(color))
                 paint.setPen(QtGui.QColor(color))
                 paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)                     
@@ -415,7 +401,7 @@ def GenerateGraph(self,  QtGui):
     paint.end()
 
 
-
+#    Statistics()
 
 
 
@@ -423,24 +409,53 @@ def GenerateGraph(self,  QtGui):
 ############################################################################
 ### 
 ############################################################################  
-#def ScrollbarData():        
-#    Xscale=data.arrXscale[data.Xscale]
-#    data.data.GraphBitMapLen=(records.LastIndex+5)/Xscale
-#    if(data.data.GraphBitMapLen==0): data.data.GraphBitMapLen=1 #prevent divisions by zero
-#    data.GraphEnd=min(records.LastIndex+5,  data.GraphStart+779*Xscale-data.Derivation)
+#def Statistics():  
+##arrStatData[[0]*4,  [0]*4,  [0]*4] # Accumulated time/phase, Amount of times/phase, Max time/phase
 #    
-#    if(data.GraphEnd<=data.Derivation): return [0,  100]
+#    #Sleep phase 1 = 30 minutes and longer
+#    #Sleep phase 2 = 15 .. 29 minutes
+#    #Sleep phase 3 = 7 .. 14 minutes
+#    #Sleep phase 4 = under 7 minutes
 #    
-#    p0=float(data.GraphStart)*100/data.data.GraphBitMapLen/Xscale
-#    p1=float(data.GraphEnd)*100/data.data.GraphBitMapLen/Xscale
-#    p1=min(100,  p1)
-##    print "--------------------"
-##    print "Scroll bar is on %:", p0, "...", p1 
-##    print "records.LastIndex:",  records.LastIndex
-##    print "data.data.GraphBitMapLen:",  data.data.GraphBitMapLen
-##    print "data.GraphEnd:",  data.GraphEnd
-#    return [p0,  p1]
-
+#    for i in range(0,  3): #clear array
+#        for j in range(0,  2): data.arrStatData[j][i]=0
+#    
+#    
+#    for i in range(0,  records.Index-data.Derivation):     
+#        print i,  records.arrData[0][i], records.arrData[3][i],  records.arrData[4][i]
+#        
+#    print "----------------------------"
+#    i=records.Index-data.Derivation-1
+#    lastindexovertrigger=records.arrData[4][i]
+#    print i,  lastindexovertrigger
+#    while(i>0):
+#        if(records.arrData[4][i] != lastindexovertrigger):
+#            diff= i - lastindexovertrigger
+#            t=diff*records.Sampling_interval*records.Value_smoothing/1000
+#            print i,  diff,  t
+#            if(t>30): #30 minutes and longer
+#                data.arrStatData[0][0]=data.arrStatData[0][0]+t #Accumulated time for phase 1
+#                data.arrStatData[0][1]=data.arrStatData[0][1]+1 #Amount of times/phase 1
+#                if(data.arrStatData[0][2]<t): data.arrStatData[0][2]=t #Max time in phase 1
+#            elif(t>15): #15 .. 29 minutes
+#                data.arrStatData[1][0]=data.arrStatData[1][0]+t #Accumulated time for phase 2
+#                data.arrStatData[1][1]=data.arrStatData[1][1]+1#Amount of times/phase 2
+#                if(data.arrStatData[1][2]<t): data.arrStatData[1][2]=t #Max time in phase 1
+#            elif(t>7): #7 .. 14 minutes
+#                data.arrStatData[2][0]=data.arrStatData[2][0]+t #Accumulated time for phase 3
+#                data.arrStatData[2][1]=data.arrStatData[2][1]+1#Amount of times/phase 3
+#                if(data.arrStatData[2][2]<t): data.arrStatData[2][2]=t #Max time in phase 1
+#            else: #under 7 minutes
+#                data.arrStatData[3][0]=data.arrStatData[3][0]+t #Accumulated time for phase 4
+#                data.arrStatData[3][1]=data.arrStatData[3][1]+1#Amount of times/phase 4
+#                if(data.arrStatData[3][2]<t): data.arrStatData[3][2]=t #Max time in phase 1
+#                
+#            lastindexovertrigger=records.arrData[4][i-1]
+#            
+#        i=i-1
+#
+##     for i in range(0,  3): data.arrStatData[3][0]=data.arrStatData[3][0]/60
+#    print data.arrStatData
 
 
 
