@@ -243,8 +243,9 @@ def InitMeasurement():
     data.StartTime=time.localtime()
     data.StartTimeSec=Tuple2Seconds(data.StartTime)
    
-    if(data.debug==False): app.timer_GetData.start(data.interval)   
-    else: app.timer_GetData.start(1)    #run very fast for testing
+#    if(data.debug==False): app.timer_GetData.start(data.interval)   
+#    else: app.timer_GetData.start(1)    #run very fast for testing
+    app.timer_GetData.start(data.interval)
     
     CreateRecordFile(data.interval)
     GetFirstEntry()
@@ -681,17 +682,13 @@ class frmRecordWindow(QMainWindow):
 
     def ZoomIn(self):
         Zoom(+1)
-         
-        self.update()
-        self.UpdateScreen()
+        ShowGraph(self)
         
 
 
     def ZoomOut(self):
         Zoom(-1)
-         
-        self.update()
-        self.UpdateScreen()
+        ShowGraph(self)
 
 
 
@@ -701,8 +698,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
          
-        self.update() 
-        self.UpdateScreen()
+        ShowGraph(self)
         
         
         
@@ -712,8 +708,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
          
-        self.update()
-        self.UpdateScreen()
+        ShowGraph(self)
 
 
 
@@ -1670,6 +1665,9 @@ class DisplayStatusDaemon:
 
 
 
+
+
+
 ###########################################################################
 ## 
 ###########################################################################
@@ -1690,7 +1688,6 @@ class MyCanvas(QtGui.QWidget):
             return
         
         if(data.ScrollToEnd==True): 
-            if(data.debug==1): print "Set scroll position to:",  data.GraphBitMapLen+10
             if(data.run==True): RecordWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
             else: ViewWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
             data.ScrollToEnd=False
